@@ -138,11 +138,11 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 51200);
 
-//@line 142 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 142 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 145 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 145 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 147 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 147 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -155,14 +155,14 @@ pref("gfx.color_management.rendering_intent", 0);
 
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.sanitize", true);
-//@line 162 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 162 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
-//@line 164 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 164 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 169 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 169 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -175,7 +175,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 185 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 185 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -523,9 +523,9 @@ pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
 pref("content.sink.event_probe_rate", 3);
-//@line 533 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 533 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 535 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 535 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -570,7 +570,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 582 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 582 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -720,6 +720,7 @@ pref("network.IDN.whitelist.sh", true);
 pref("network.IDN.whitelist.th", true);
 pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
+pref("network.IDN.whitelist.ua", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
@@ -728,6 +729,8 @@ pref("network.IDN.whitelist.xn--mgbaam7a8h", true);
 // cn, China, .<China> with variants
 pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
 pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// eg, Egypt, .<Masr>
+pref("network.IDN.whitelist.xn--wgbh1c", true);
 // hk, Hong Kong, .<Hong Kong>
 pref("network.IDN.whitelist.xn--j6w193g", true);
 // ir, Iran, <.Iran> with variants
@@ -834,7 +837,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 851 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 854 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -853,9 +856,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 871 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 874 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 878 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 881 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1217,15 +1220,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1618 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 1621 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2035 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2038 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2236 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2239 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2330 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2333 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2333 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2336 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1493,15 +1496,15 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2603 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2606 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2671 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2674 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2697 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2700 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2717 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2720 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
-//@line 2725 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2728 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1525,7 +1528,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2754 "/builds/moz2_slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
+//@line 2757 "/builds/slave/191-lnx-ntly/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
